==> zzyj-outputvalcount-impl-3.0.0-20250610.072817-356-sources.jar: com/ejianc/business/worklog/bean/OrgIndexStatisticsDetailEntity.java <==
package com.ejianc.business.worklog.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 指标线上化-指标达成统计详情
 * 
 * @author generator
 * 
 */
 @TableName("t_outputvalcount_org_index_statistics_detail")
public class OrgIndexStatisticsDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="zhu_id")
    private Long zhuId; // 主表id
    @TableField(value="manage_type")
    private String manageType; // 管理模块
    @TableField(value="department_Id")
    private Long departmentId; // 责任部门
    @TableField(value="department_name")
    private String departmentName; // 
    @TableField(value="index_source")
    private String indexSource; // 指标来源
    @TableField(value="index_remark")
    private String indexRemark; // 指标内容
    @TableField(value="index_name")
    private String indexName; // 指标名称
    @TableField(value="index_type")
    private String indexType; // 指标分类(1-定量类 2-定性类 3-完成率类)
    @TableField(value="index_rule")
    private String indexRule; // 指标取数规则
    @TableField(value="index_from")
    private String indexFrom; // 指标制定依据
    @TableField(value="index_formula")
    private String indexFormula; // 指标测算公式
    @TableField(value="index_year")
    private Integer indexYear; // 年份
    @TableField(value="duty_person")
    private String dutyPerson; // 主控人员
    @TableField(value="duty_person_name")
    private String dutyPersonName; // 主控人员名称
    @TableField(value="index_per")
    private BigDecimal indexPer; // 重要性占比
    @TableField(value="index_progress")
    private String indexProgress; // 最新进展
    @TableField(value="index_evaluate")
    private String indexEvaluate; // 评价
    @TableField(value="evaluate_date")
    private Date evaluateDate; // 评价日期
    @TableField(value="progress_date")
    private Date progressDate; // 最新进展日期
    @TableField(value="index_statistic")
    private String indexStatistic; // 完成总结
    @TableField(value = "index_id")
    private Long indexId;//指标id
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getZhuId() {
        return zhuId;
    }

    public void setZhuId(Long zhuId) {
        this.zhuId = zhuId;
    }
    public String getManageType() {
        return manageType;
    }

    public void setManageType(String manageType) {
        this.manageType = manageType;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getIndexSource() {
        return indexSource;
    }

    public void setIndexSource(String indexSource) {
        this.indexSource = indexSource;
    }
    public String getIndexRemark() {
        return indexRemark;
    }

    public void setIndexRemark(String indexRemark) {
        this.indexRemark = indexRemark;
    }
    public String getIndexName() {
        return indexName;
    }

    public void setIndexName(String indexName) {
        this.indexName = indexName;
    }
    public String getIndexType() {
        return indexType;
    }

    public void setIndexType(String indexType) {
        this.indexType = indexType;
    }
    public String getIndexRule() {
        return indexRule;
    }

    public void setIndexRule(String indexRule) {
        this.indexRule = indexRule;
    }
    public String getIndexFrom() {
        return indexFrom;
    }

    public void setIndexFrom(String indexFrom) {
        this.indexFrom = indexFrom;
    }
    public String getIndexFormula() {
        return indexFormula;
    }

    public void setIndexFormula(String indexFormula) {
        this.indexFormula = indexFormula;
    }
    public Integer getIndexYear() {
        return indexYear;
    }

    public void setIndexYear(Integer indexYear) {
        this.indexYear = indexYear;
    }
    public String getDutyPerson() {
        return dutyPerson;
    }

    public void setDutyPerson(String dutyPerson) {
        this.dutyPerson = dutyPerson;
    }
    public String getDutyPersonName() {
        return dutyPersonName;
    }

    public void setDutyPersonName(String dutyPersonName) {
        this.dutyPersonName = dutyPersonName;
    }
    public BigDecimal getIndexPer() {
        return indexPer;
    }

    public void setIndexPer(BigDecimal indexPer) {
        this.indexPer = indexPer;
    }
    public String getIndexProgress() {
        return indexProgress;
    }

    public void setIndexProgress(String indexProgress) {
        this.indexProgress = indexProgress;
    }
    public String getIndexEvaluate() {
        return indexEvaluate;
    }

    public void setIndexEvaluate(String indexEvaluate) {
        this.indexEvaluate = indexEvaluate;
    }
    public Date getEvaluateDate() {
        return evaluateDate;
    }

    public void setEvaluateDate(Date evaluateDate) {
        this.evaluateDate = evaluateDate;
    }
    public Date getProgressDate() {
        return progressDate;
    }

    public void setProgressDate(Date progressDate) {
        this.progressDate = progressDate;
    }
    public String getIndexStatistic() {
        return indexStatistic;
    }

    public void setIndexStatistic(String indexStatistic) {
        this.indexStatistic = indexStatistic;
    }

    public Long getIndexId() {
        return indexId;
    }

    public void setIndexId(Long indexId) {
        this.indexId = indexId;
    }
}

==> zzyj-outputvalcount-impl-3.0.0-20250814.020320-374-sources.jar: com/ejianc/business/worklog/bean/OrgIndexStatisticsDetailEntity.java <==
package com.ejianc.business.worklog.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 指标线上化-指标达成统计详情
 * 
 * @author generator
 * 
 */
 @TableName("t_outputvalcount_org_index_statistics_detail")
public class OrgIndexStatisticsDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="zhu_id")
    private Long zhuId; // 主表id
    @TableField(value="manage_type")
    private String manageType; // 管理模块
    @TableField(value="department_Id")
    private Long departmentId; // 责任部门
    @TableField(value="department_name")
    private String departmentName; // 
    @TableField(value="index_source")
    private String indexSource; // 指标来源
    @TableField(value="index_remark")
    private String indexRemark; // 指标内容
    @TableField(value="index_name")
    private String indexName; // 指标名称
    @TableField(value="index_type")
    private String indexType; // 指标分类(1-定量类 2-定性类 3-完成率类)
    @TableField(value="index_rule")
    private String indexRule; // 指标取数规则
    @TableField(value="index_from")
    private String indexFrom; // 指标制定依据
    @TableField(value="index_formula")
    private String indexFormula; // 指标测算公式
    @TableField(value="index_year")
    private Integer indexYear; // 年份
    @TableField(value="duty_person")
    private String dutyPerson; // 主控人员
    @TableField(value="duty_person_name")
    private String dutyPersonName; // 主控人员名称
    @TableField(value="index_per")
    private BigDecimal indexPer; // 重要性占比
    @TableField(value="index_progress")
    private String indexProgress; // 最新进展
    @TableField(value="index_evaluate")
    private String indexEvaluate; // 评价
    @TableField(value="evaluate_date")
    private Date evaluateDate; // 评价日期
    @TableField(value="progress_date")
    private Date progressDate; // 最新进展日期
    @TableField(value="index_statistic")
    private String indexStatistic; // 完成总结
    @TableField(value = "index_id")
    private Long indexId;//指标id
    @TableField(value = "finish_type")
    private String finishType;
    @TableField(value = "finish_per")
    private String finishPer;
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getZhuId() {
        return zhuId;
    }

    public void setZhuId(Long zhuId) {
        this.zhuId = zhuId;
    }
    public String getManageType() {
        return manageType;
    }

    public void setManageType(String manageType) {
        this.manageType = manageType;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getIndexSource() {
        return indexSource;
    }

    public void setIndexSource(String indexSource) {
        this.indexSource = indexSource;
    }
    public String getIndexRemark() {
        return indexRemark;
    }

    public void setIndexRemark(String indexRemark) {
        this.indexRemark = indexRemark;
    }
    public String getIndexName() {
        return indexName;
    }

    public void setIndexName(String indexName) {
        this.indexName = indexName;
    }
    public String getIndexType() {
        return indexType;
    }

    public void setIndexType(String indexType) {
        this.indexType = indexType;
    }
    public String getIndexRule() {
        return indexRule;
    }

    public void setIndexRule(String indexRule) {
        this.indexRule = indexRule;
    }
    public String getIndexFrom() {
        return indexFrom;
    }

    public void setIndexFrom(String indexFrom) {
        this.indexFrom = indexFrom;
    }
    public String getIndexFormula() {
        return indexFormula;
    }

    public void setIndexFormula(String indexFormula) {
        this.indexFormula = indexFormula;
    }
    public Integer getIndexYear() {
        return indexYear;
    }

    public void setIndexYear(Integer indexYear) {
        this.indexYear = indexYear;
    }
    public String getDutyPerson() {
        return dutyPerson;
    }

    public void setDutyPerson(String dutyPerson) {
        this.dutyPerson = dutyPerson;
    }
    public String getDutyPersonName() {
        return dutyPersonName;
    }

    public void setDutyPersonName(String dutyPersonName) {
        this.dutyPersonName = dutyPersonName;
    }
    public BigDecimal getIndexPer() {
        return indexPer;
    }

    public void setIndexPer(BigDecimal indexPer) {
        this.indexPer = indexPer;
    }
    public String getIndexProgress() {
        return indexProgress;
    }

    public void setIndexProgress(String indexProgress) {
        this.indexProgress = indexProgress;
    }
    public String getIndexEvaluate() {
        return indexEvaluate;
    }

    public void setIndexEvaluate(String indexEvaluate) {
        this.indexEvaluate = indexEvaluate;
    }
    public Date getEvaluateDate() {
        return evaluateDate;
    }

    public void setEvaluateDate(Date evaluateDate) {
        this.evaluateDate = evaluateDate;
    }
    public Date getProgressDate() {
        return progressDate;
    }

    public void setProgressDate(Date progressDate) {
        this.progressDate = progressDate;
    }
    public String getIndexStatistic() {
        return indexStatistic;
    }

    public void setIndexStatistic(String indexStatistic) {
        this.indexStatistic = indexStatistic;
    }

    public Long getIndexId() {
        return indexId;
    }

    public void setIndexId(Long indexId) {
        this.indexId = indexId;
    }

    public String getFinishType() {
        return finishType;
    }

    public void setFinishType(String finishType) {
        this.finishType = finishType;
    }

    public String getFinishPer() {
        return finishPer;
    }

    public void setFinishPer(String finishPer) {
        this.finishPer = finishPer;
    }
}
